pub struct BatchSumcheckOutput<F> {
pub batch_coeff: F,
pub eval: F,
pub challenges: Vec<F>,
}Expand description
The reduced output of a sumcheck verification.
The batch_verify function reduces a set of claims on multivariate polynomials over the
boolean hypercube to their evaluation at a challenge point. See the function docstring for
details.
Fields
batch_coeff: FThe challenge value of the batching variable.
eval: FThe evaluation of the sumcheck multivariate at the challenge point.
challenges: Vec<F>Verifier challenges for each round of the sumcheck protocol.
One challenge is generated per variable in the multivariate polynomial, with challenges[i] corresponding to the i-th round of the protocol.
Note: reverse when folding high-to-low to obtain evaluation claim.