pub fn batch_verify<F, C>(
n_vars: usize,
degree: usize,
sums: &[C::Elem],
channel: &mut C,
) -> Result<BatchSumcheckOutput<C::Elem>, Error>where
F: Field,
C: IPVerifierChannel<F>,Expand description
Verify a batched sumcheck protocol interaction.
The batched sumcheck verifier reduces a set of claims about the sums of multivariate polynomials
over the boolean hypercube to their evaluation at a (shared) challenge point. This is achieved
by constructing an n_vars + 1-variate polynomial whose coefficients in the “new variable” are
the individual sum claims and evaluating it at a random point.