pub fn verify<F, C>(
n_vars: usize,
degree: usize,
sum: C::Elem,
channel: &mut C,
) -> Result<SumcheckOutput<C::Elem>, Error>where
F: Field,
C: IPVerifierChannel<F>,Expand description
Verify a sumcheck protocol interaction.
The sumcheck verifier reduces a claim about the sum of a multivariate polynomial over the boolean hypercube to its evaluation at a challenge point.
Arguments
n_vars- The number of variables in the multivariate polynomialdegree- The degree of the univariate polynomial in each roundsum- The claimed sum of the multivariate polynomial over the boolean hypercubechannel- The channel for receiving prover messages and sampling challenges
Returns
Returns a Result containing the SumcheckOutput with the reduced evaluation and challenge
point, or an error if verification fails.